@@ -10,24 +10,23 @@ class Help(urwid.WidgetWrap):
 
         if self.target:
             tname = self.target.__class__.__name__
-            self.ui.set_header("Help: " + tname)
+            self.ui.set_header([urwid.Text("help: " + tname)])
         else:
-            self.ui.set_header("Help")
+            self.ui.set_header([urwid.Text("help")])
 
         pile = []
 
-
         if self.target and hasattr(self.target, 'keys'):
             pile.append(urwid.Text('%s commands:' % (tname)))
             pile.append(urwid.Text(''))
-            for key, cmd in sorted(self.target.keys.iteritems()):
+            for key, cmd in self.target.keys.iteritems():
                 pile.append(self.row('target', cmd, key))
             pile.append(urwid.Text(''))
             pile.append(urwid.Text(''))
 
         pile.append(urwid.Text('Global commands:'))
         pile.append(urwid.Text(''))
-        for key, cmd in sorted(self.ui.keys.iteritems()):
+        for key, cmd in self.ui.keys.iteritems():
             pile.append(self.row('ui', cmd, key))
 
         w = urwid.Filler(urwid.Pile(pile))
@@ -35,13 +34,9 @@ class Help(urwid.WidgetWrap):
 
     def row(self, c, cmd, key):
         hstring = eval('str(self.%s.%s.__doc__)' % (c, cmd))
-        return urwid.Columns(
-            [
-                ('fixed', 8,
-                 urwid.Text(key)),
-                urwid.Text(hstring),
-                 ]
-                )
+        return urwid.Columns([('fixed', 10, urwid.Text(key)),
+                              urwid.Text(hstring),
+                              ])
 
     def keypress(self, size, key):
         self.ui.keypress(key)
